summaryrefslogtreecommitdiffstats
path: root/src/inactivity.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/inactivity.cpp')
-rw-r--r--src/inactivity.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/inactivity.cpp b/src/inactivity.cpp
index 48969a9..28fe520 100644
--- a/src/inactivity.cpp
+++ b/src/inactivity.cpp
@@ -285,15 +285,15 @@ void inactivity::checkBlacklisted(){
proc = NULL;
}
- proc = new KProcess;
+ proc = new TDEProcess;
*proc << "pidof" << blacklist;
- connect( proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)),this,
- TQT_SLOT(getPIDs(KProcess *, char *, int)));
- connect( proc, TQT_SIGNAL(processExited(KProcess *)),
- TQT_SLOT(getPIDsExited(KProcess *)));
+ connect( proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),this,
+ TQT_SLOT(getPIDs(TDEProcess *, char *, int)));
+ connect( proc, TQT_SIGNAL(processExited(TDEProcess *)),
+ TQT_SLOT(getPIDsExited(TDEProcess *)));
- if (!proc->start(KProcess::NotifyOnExit, KProcess::AllOutput))
+ if (!proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput))
{
emit displayErrorMsg(i18n("Could not start 'pidof'. "
"Could not autosuspend the machine.\n"
@@ -311,11 +311,11 @@ void inactivity::checkBlacklisted(){
/*!
* \b TQT_SLOT to get the return of the command pidof and parse this to set
* \ref blacklisted_running .
* \param *proc pointer to the sending KProcess
* \param *buffer the char pointer to the output of the process to stdout
* \param *length the length of the buffer
*/
-void inactivity::getPIDs(KProcess */*proc*/, char *buffer, int /*length*/) {
+void inactivity::getPIDs(TDEProcess */*proc*/, char *buffer, int /*length*/) {
kdDebugFuncIn(trace);
TQString pids(buffer);
@@ -345,7 +345,7 @@ void inactivity::getPIDs(KProcess */*proc*/, char *buffer, int /*length*/) {
* \b TQT_SLOT which called if the call of pidof is exited
* \param proc the KPocess which called this SLOT
*/
-void inactivity::getPIDsExited(KProcess *proc){
+void inactivity::getPIDsExited(TDEProcess *proc){
kdDebugFuncIn(trace);
pidof_call_returned = true;
@@ -311,11 +311,11 @@ void inactivity::checkBlacklisted(){
* \b TQT_SLOT to get the return of the command pidof and parse this to set
* \ref blacklisted_running .
- * \param *proc pointer to the sending KProcess
+ * \param *proc pointer to the sending TDEProcess
* \param *buffer the char pointer to the output of the process to stdout
* \param *length the length of the buffer